@@ -9,32 +9,32 @@ build_time_vars = {'ABIFLAGS': '',
  'ANDROID_API_LEVEL': 0,
  'AR': 'ar',
  'ARFLAGS': 'rcs',
- 'BASECFLAGS': '-Wno-unused-result -Wsign-compare',
+ 'BASECFLAGS': '',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/bin',
- 'BINLIBDEST': '/usr/lib/python3.10',
- 'BLDLIBRARY': '-L. -lpython3.10',
+ 'BINLIBDEST': '/usr/lib/python3.11',
+ 'BLDLIBRARY': '-L. -lpython3.11',
  'BLDSHARED': 'gcc -shared -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
               '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'BOOTSTRAP_HEADERS': '\\',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'armv7l-unknown-linux-gnueabihf',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-           '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
-           '-fstack-protector-strong -fno-plt -fexceptions         '
-           '-Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         '
-           '-fstack-clash-protection -march=armv7-a -mfloat-abi=hard '
+ 'CFLAGS': '-DNDEBUG -g -fwrapv -O3 -Wall -march=armv7-a -mfloat-abi=hard '
            '-mfpu=neon -O3 -pipe -fstack-protector-strong -fno-plt '
            '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
            '-Werror=format-security         -fstack-clash-protection '
            '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
            '-fstack-protector-strong -fno-plt -fexceptions         '
            '-Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         '
-           '-fstack-clash-protection',
+           '-fstack-clash-protection -march=armv7-a -mfloat-abi=hard '
+           '-mfpu=neon -O3 -pipe -fstack-protector-strong -fno-plt '
+           '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+           '-Werror=format-security         -fstack-clash-protection',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
@@ -44,14 +44,12 @@ build_time_vars = {'ABIFLAGS': '',
                      '-fstack-protector-strong -fno-plt -fexceptions         '
                      '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                      '-Werror=format-security         -fstack-clash-protection',
- 'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
-                            '-Wno-unused-parameter '
-                            '-Wno-missing-field-initializers '
-                            '-Werror=implicit-function-declaration '
+ 'CONFIGURE_CFLAGS_NODIST': '-std=c11 -Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '',
  'CONFIGURE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'CONFIGURE_LDFLAGS_NODIST': '',
+ 'CONFIGURE_LDFLAGS_NOLTO': '',
  'CONFIG_ARGS': "'--prefix=/usr' '--enable-shared' '--with-computed-gotos' "
                 "'--without-lto' '--enable-ipv6' '--with-system-expat' "
                 "'--with-dbmliborder=gdbm:ndbm' '--with-system-libmpdec' "
@@ -64,19 +62,26 @@ build_time_vars = {'ABIFLAGS': '',
                 "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now' "
                 "'CPPFLAGS='",
  'CONFINCLUDEDIR': '/usr/include',
- 'CONFINCLUDEPY': '/usr/include/python3.10',
+ 'CONFINCLUDEPY': '/usr/include/python3.11',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python/src/Python-3.10.10/coverage.info',
- 'COVERAGE_REPORT': '/build/python/src/Python-3.10.10/lcov-report',
- 'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
-                            'report"',
+ 'COVERAGE_INFO': '/build/python/src/Python-3.11.3/coverage.info',
+ 'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
+ 'COVERAGE_REPORT': '/build/python/src/Python-3.11.3/lcov-report',
+ 'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
+                            '--title "CPython 3.11 LCOV report [commit $(shell '
+                            ')]"',
  'CPPFLAGS': '-I. -I./Include',
  'CXX': 'g++',
- 'DESTDIRS': '/usr /usr/lib /usr/lib/python3.10 '
-             '/usr/lib/python3.10/lib-dynload',
- 'DESTLIB': '/usr/lib/python3.10',
+ 'DECIMAL_CFLAGS': '-DCONFIG_32=1 -DANSI=1',
+ 'DECIMAL_LDFLAGS': '-lmpdec',
+ 'DEEPFREEZE_DEPS': './Tools/scripts/deepfreeze.py _bootstrap_python '
+                    './Programs/_freeze_module.py \\',
+ 'DEEPFREEZE_OBJS': 'Python/deepfreeze/deepfreeze.o',
+ 'DESTDIRS': '/usr /usr/lib /usr/lib/python3.11 '
+             '/usr/lib/python3.11/lib-dynload',
+ 'DESTLIB': '/usr/lib/python3.11',
  'DESTPATH': '',
- 'DESTSHARED': '/usr/lib/python3.10/lib-dynload',
+ 'DESTSHARED': '/usr/lib/python3.11/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
@@ -98,19 +103,26 @@ build_time_vars = {'ABIFLAGS': '',
  'ENSUREPIP': 'no',
  'EXE': '',
  'EXEMODE': 755,
- 'EXPERIMENTAL_ISOLATED_SUBINTERPRETERS': 0,
+ 'EXPAT_CFLAGS': '',
+ 'EXPAT_LDFLAGS': '-lexpat',
  'EXPORTSFROM': '',
  'EXPORTSYMS': '',
  'EXTRATESTOPTS': '',
- 'EXT_SUFFIX': '.cpython-310-arm-linux-gnueabihf.so',
+ 'EXT_SUFFIX': '.cpython-311-arm-linux-gnueabihf.so',
  'FILEMODE': 644,
  'FLOAT_WORDS_BIGENDIAN': 0,
- 'FLOCK_NEEDS_LIBBSD': 0,
+ 'FREEZE_MODULE': './_bootstrap_python ./Programs/_freeze_module.py',
+ 'FREEZE_MODULE_BOOTSTRAP': './Programs/_freeze_module',
+ 'FREEZE_MODULE_BOOTSTRAP_DEPS': 'Programs/_freeze_module',
+ 'FREEZE_MODULE_DEPS': '_bootstrap_python ./Programs/_freeze_module.py',
+ 'FROZEN_FILES_IN': '\\',
+ 'FROZEN_FILES_OUT': '\\',
  'GETPGRP_HAVE_ARG': 0,
  'GITBRANCH': '',
  'GITTAG': '',
  'GITVERSION': '',
  'GNULD': 'yes',
+ 'HAVE_ACCEPT': 1,
  'HAVE_ACCEPT4': 1,
  'HAVE_ACOSH': 1,
  'HAVE_ADDRINFO': 1,
@@ -121,6 +133,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ASINH': 1,
  'HAVE_ASM_TYPES_H': 1,
  'HAVE_ATANH': 1,
+ 'HAVE_BIND': 1,
  'HAVE_BIND_TEXTDOMAIN_CODESET': 1,
  'HAVE_BLUETOOTH_BLUETOOTH_H': 1,
  'HAVE_BLUETOOTH_H': 0,
@@ -133,18 +146,21 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_BROKEN_SEM_GETVALUE': 0,
  'HAVE_BROKEN_UNSETENV': 0,
  'HAVE_BUILTIN_ATOMIC': 1,
+ 'HAVE_BZLIB_H': 0,
  'HAVE_CHFLAGS': 0,
+ 'HAVE_CHMOD': 1,
  'HAVE_CHOWN': 1,
  'HAVE_CHROOT': 1,
  'HAVE_CLOCK': 1,
  'HAVE_CLOCK_GETRES': 1,
  'HAVE_CLOCK_GETTIME': 1,
+ 'HAVE_CLOCK_NANOSLEEP': 1,
  'HAVE_CLOCK_SETTIME': 1,
  'HAVE_CLOSE_RANGE': 1,
  'HAVE_COMPUTED_GOTOS': 1,
  'HAVE_CONFSTR': 1,
  'HAVE_CONIO_H': 0,
- 'HAVE_COPYSIGN': 1,
+ 'HAVE_CONNECT': 1,
  'HAVE_COPY_FILE_RANGE': 1,
  'HAVE_CRYPT_H': 1,
  'HAVE_CRYPT_R': 1,
@@ -162,9 +178,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_CURSES_TYPEAHEAD': 1,
  'HAVE_CURSES_USE_ENV': 1,
  'HAVE_CURSES_WCHGAT': 1,
- 'HAVE_DECL_ISFINITE': 1,
- 'HAVE_DECL_ISINF': 1,
- 'HAVE_DECL_ISNAN': 1,
+ 'HAVE_DB_H': 1,
  'HAVE_DECL_RTLD_DEEPBIND': 1,
  'HAVE_DECL_RTLD_GLOBAL': 1,
  'HAVE_DECL_RTLD_LAZY': 1,
@@ -183,6 +197,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_DIRFD': 1,
  'HAVE_DLFCN_H': 1,
  'HAVE_DLOPEN': 1,
+ 'HAVE_DUP': 1,
  'HAVE_DUP2': 1,
  'HAVE_DUP3': 1,
  'HAVE_DYLD_SHARED_CACHE_CONTAINS_PATH': 0,
@@ -209,9 +224,9 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_FDOPENDIR': 1,
  'HAVE_FDWALK': 0,
  'HAVE_FEXECVE': 1,
- 'HAVE_FINITE': 1,
  'HAVE_FLOCK': 1,
  'HAVE_FORK': 1,
+ 'HAVE_FORK1': 0,
  'HAVE_FORKPTY': 1,
  'HAVE_FPATHCONF': 1,
  'HAVE_FSEEK64': 0,
@@ -227,23 +242,31 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_FUTIMES': 1,
  'HAVE_FUTIMESAT': 1,
  'HAVE_GAI_STRERROR': 1,
- 'HAVE_GAMMA': 1,
  'HAVE_GCC_ASM_FOR_MC68881': 0,
  'HAVE_GCC_ASM_FOR_X64': 0,
  'HAVE_GCC_ASM_FOR_X87': 0,
  'HAVE_GCC_UINT128_T': 0,
+ 'HAVE_GDBM_DASH_NDBM_H': 0,
+ 'HAVE_GDBM_H': 1,
+ 'HAVE_GDBM_NDBM_H': 0,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETC_UNLOCKED': 1,
+ 'HAVE_GETEGID': 1,
  'HAVE_GETENTROPY': 1,
+ 'HAVE_GETEUID': 1,
+ 'HAVE_GETGID': 1,
+ 'HAVE_GETGRGID': 1,
  'HAVE_GETGRGID_R': 1,
  'HAVE_GETGRNAM_R': 1,
  'HAVE_GETGROUPLIST': 1,
  'HAVE_GETGROUPS': 1,
- 'HAVE_GETHOSTBYNAME': 0,
+ 'HAVE_GETHOSTBYADDR': 1,
+ 'HAVE_GETHOSTBYNAME': 1,
  'HAVE_GETHOSTBYNAME_R': 1,
  'HAVE_GETHOSTBYNAME_R_3_ARG': 0,
  'HAVE_GETHOSTBYNAME_R_5_ARG': 0,
  'HAVE_GETHOSTBYNAME_R_6_ARG': 1,
+ 'HAVE_GETHOSTNAME': 1,
  'HAVE_GETITIMER': 1,
  'HAVE_GETLOADAVG': 1,
  'HAVE_GETLOGIN': 1,
@@ -253,26 +276,34 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GETPGID': 1,
  'HAVE_GETPGRP': 1,
  'HAVE_GETPID': 1,
+ 'HAVE_GETPPID': 1,
  'HAVE_GETPRIORITY': 1,
+ 'HAVE_GETPROTOBYNAME': 1,
  'HAVE_GETPWENT': 1,
  'HAVE_GETPWNAM_R': 1,
+ 'HAVE_GETPWUID': 1,
  'HAVE_GETPWUID_R': 1,
  'HAVE_GETRANDOM': 1,
  'HAVE_GETRANDOM_SYSCALL': 1,
  'HAVE_GETRESGID': 1,
  'HAVE_GETRESUID': 1,
+ 'HAVE_GETRUSAGE': 1,
+ 'HAVE_GETSERVBYNAME': 1,
+ 'HAVE_GETSERVBYPORT': 1,
  'HAVE_GETSID': 1,
+ 'HAVE_GETSOCKNAME': 1,
  'HAVE_GETSPENT': 1,
  'HAVE_GETSPNAM': 1,
+ 'HAVE_GETUID': 1,
  'HAVE_GETWD': 1,
  'HAVE_GLIBC_MEMMOVE_BUG': 0,
  'HAVE_GRP_H': 1,
  'HAVE_HSTRERROR': 1,
  'HAVE_HTOLE64': 1,
- 'HAVE_HYPOT': 1,
  'HAVE_IEEEFP_H': 0,
  'HAVE_IF_NAMEINDEX': 1,
  'HAVE_INET_ATON': 1,
+ 'HAVE_INET_NTOA': 1,
  'HAVE_INET_PTON': 1,
  'HAVE_INITGROUPS': 1,
  'HAVE_INTTYPES_H': 1,
@@ -286,16 +317,19 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LCHFLAGS': 0,
  'HAVE_LCHMOD': 0,
  'HAVE_LCHOWN': 1,
- 'HAVE_LGAMMA': 1,
+ 'HAVE_LIBB2': 0,
+ 'HAVE_LIBDB': 1,
  'HAVE_LIBDL': 1,
  'HAVE_LIBDLD': 0,
+ 'HAVE_LIBGDBM_COMPAT': 1,
  'HAVE_LIBIEEE': 0,
  'HAVE_LIBINTL_H': 1,
+ 'HAVE_LIBNDBM': 0,
  'HAVE_LIBREADLINE': 1,
  'HAVE_LIBRESOLV': 0,
  'HAVE_LIBSENDFILE': 0,
+ 'HAVE_LIBSQLITE3': 1,
  'HAVE_LIBUTIL_H': 0,
- 'HAVE_LIBUUID': 1,
  'HAVE_LINK': 1,
  'HAVE_LINKAT': 1,
  'HAVE_LINUX_AUXVEC_H': 1,
@@ -309,15 +343,19 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LINUX_NETLINK_H': 1,
  'HAVE_LINUX_QRTR_H': 1,
  'HAVE_LINUX_RANDOM_H': 1,
+ 'HAVE_LINUX_SOUNDCARD_H': 1,
  'HAVE_LINUX_TIPC_H': 1,
  'HAVE_LINUX_VM_SOCKETS_H': 1,
  'HAVE_LINUX_WAIT_H': 1,
+ 'HAVE_LISTEN': 1,
  'HAVE_LOCKF': 1,
  'HAVE_LOG1P': 1,
  'HAVE_LOG2': 1,
+ 'HAVE_LOGIN_TTY': 1,
  'HAVE_LONG_DOUBLE': 1,
  'HAVE_LSTAT': 1,
  'HAVE_LUTIMES': 1,
+ 'HAVE_LZMA_H': 0,
  'HAVE_MADVISE': 1,
  'HAVE_MAKEDEV': 1,
  'HAVE_MBRTOWC': 1,
@@ -332,16 +370,23 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_MKTIME': 1,
  'HAVE_MMAP': 1,
  'HAVE_MREMAP': 1,
+ 'HAVE_NANOSLEEP': 1,
  'HAVE_NCURSES_H': 1,
+ 'HAVE_NDBM_H': 1,
  'HAVE_NDIR_H': 0,
+ 'HAVE_NETCAN_CAN_H': 0,
+ 'HAVE_NETDB_H': 1,
+ 'HAVE_NETINET_IN_H': 1,
  'HAVE_NETPACKET_PACKET_H': 1,
  'HAVE_NET_IF_H': 1,
  'HAVE_NICE': 1,
  'HAVE_NON_UNICODE_WCHAR_T_REPRESENTATION': 0,
  'HAVE_OPENAT': 1,
+ 'HAVE_OPENDIR': 1,
  'HAVE_OPENPTY': 1,
  'HAVE_PATHCONF': 1,
  'HAVE_PAUSE': 1,
+ 'HAVE_PIPE': 1,
  'HAVE_PIPE2': 1,
  'HAVE_PLOCK': 0,
  'HAVE_POLL': 1,
@@ -363,6 +408,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_PTHREAD_INIT': 0,
  'HAVE_PTHREAD_KILL': 1,
  'HAVE_PTHREAD_SIGMASK': 1,
+ 'HAVE_PTHREAD_STUBS': 0,
  'HAVE_PTY_H': 1,
  'HAVE_PWRITE': 1,
  'HAVE_PWRITEV': 1,
@@ -371,6 +417,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_READLINKAT': 1,
  'HAVE_READV': 1,
  'HAVE_REALPATH': 1,
+ 'HAVE_RECVFROM': 1,
  'HAVE_RENAMEAT': 1,
  'HAVE_RL_APPEND_HISTORY': 1,
  'HAVE_RL_CATCH_SIGNAL': 1,
@@ -380,7 +427,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_RL_COMPLETION_SUPPRESS_APPEND': 1,
  'HAVE_RL_PRE_INPUT_HOOK': 1,
  'HAVE_RL_RESIZE_TERMINAL': 1,
- 'HAVE_ROUND': 1,
+ 'HAVE_RPC_RPC_H': 1,
  'HAVE_RTPSPAWN': 0,
  'HAVE_SCHED_GET_PRIORITY_MAX': 1,
  'HAVE_SCHED_H': 1,
@@ -394,12 +441,14 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SEM_TIMEDWAIT': 1,
  'HAVE_SEM_UNLINK': 1,
  'HAVE_SENDFILE': 1,
+ 'HAVE_SENDTO': 1,
  'HAVE_SETEGID': 1,
  'HAVE_SETEUID': 1,
  'HAVE_SETGID': 1,
  'HAVE_SETGROUPS': 1,
  'HAVE_SETHOSTNAME': 1,
  'HAVE_SETITIMER': 1,
+ 'HAVE_SETJMP_H': 1,
  'HAVE_SETLOCALE': 1,
  'HAVE_SETPGID': 1,
  'HAVE_SETPGRP': 1,
@@ -409,11 +458,13 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SETRESUID': 1,
  'HAVE_SETREUID': 1,
  'HAVE_SETSID': 1,
+ 'HAVE_SETSOCKOPT': 1,
  'HAVE_SETUID': 1,
  'HAVE_SETVBUF': 1,
  'HAVE_SHADOW_H': 1,
  'HAVE_SHM_OPEN': 1,
  'HAVE_SHM_UNLINK': 1,
+ 'HAVE_SHUTDOWN': 1,
  'HAVE_SIGACTION': 1,
  'HAVE_SIGALTSTACK': 1,
  'HAVE_SIGFILLSET': 1,
@@ -429,6 +480,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SOCKADDR_ALG': 1,
  'HAVE_SOCKADDR_SA_LEN': 0,
  'HAVE_SOCKADDR_STORAGE': 1,
+ 'HAVE_SOCKET': 1,
  'HAVE_SOCKETPAIR': 1,
  'HAVE_SPAWN_H': 1,
  'HAVE_SPLICE': 1,
@@ -460,6 +512,8 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYNC': 1,
  'HAVE_SYSCONF': 1,
  'HAVE_SYSEXITS_H': 1,
+ 'HAVE_SYSLOG_H': 1,
+ 'HAVE_SYSTEM': 1,
  'HAVE_SYS_AUDIOIO_H': 0,
  'HAVE_SYS_AUXV_H': 1,
  'HAVE_SYS_BSDTTY_H': 0,
@@ -486,6 +540,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYS_SELECT_H': 1,
  'HAVE_SYS_SENDFILE_H': 1,
  'HAVE_SYS_SOCKET_H': 1,
+ 'HAVE_SYS_SOUNDCARD_H': 1,
  'HAVE_SYS_STATVFS_H': 1,
  'HAVE_SYS_STAT_H': 1,
  'HAVE_SYS_SYSCALL_H': 1,
@@ -505,7 +560,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_TEMPNAM': 1,
  'HAVE_TERMIOS_H': 1,
  'HAVE_TERM_H': 1,
- 'HAVE_TGAMMA': 1,
  'HAVE_TIMEGM': 1,
  'HAVE_TIMES': 1,
  'HAVE_TMPFILE': 1,
@@ -513,8 +567,9 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_TMPNAM_R': 1,
  'HAVE_TM_ZONE': 1,
  'HAVE_TRUNCATE': 1,
+ 'HAVE_TTYNAME': 1,
  'HAVE_TZNAME': 0,
- 'HAVE_UCS4_TCL': 0,
+ 'HAVE_UMASK': 1,
  'HAVE_UNAME': 1,
  'HAVE_UNISTD_H': 1,
  'HAVE_UNLINKAT': 1,
@@ -523,12 +578,14 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_UTIMENSAT': 1,
  'HAVE_UTIMES': 1,
  'HAVE_UTIME_H': 1,
+ 'HAVE_UTMP_H': 1,
  'HAVE_UUID_CREATE': 0,
  'HAVE_UUID_ENC_BE': 0,
  'HAVE_UUID_GENERATE_TIME_SAFE': 1,
- 'HAVE_UUID_H': 0,
- 'HAVE_UUID_UUID_H': 1,
+ 'HAVE_UUID_H': 1,
+ 'HAVE_UUID_UUID_H': 0,
  'HAVE_VFORK': 1,
+ 'HAVE_WAIT': 1,
  'HAVE_WAIT3': 1,
  'HAVE_WAIT4': 1,
  'HAVE_WAITID': 1,
@@ -541,47 +598,89 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_WORKING_TZSET': 1,
  'HAVE_WRITEV': 1,
  'HAVE_ZLIB_COPY': 1,
+ 'HAVE_ZLIB_H': 0,
  'HAVE__GETPTY': 0,
+ 'HOSTRUNNER': '',
  'HOST_GNU_TYPE': 'armv7l-unknown-linux-gnueabihf',
- 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.10 '
-                   '/usr/include/python3.10',
+ 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.11 '
+                   '/usr/include/python3.11',
  'INCLUDEDIR': '/usr/include',
- 'INCLUDEPY': '/usr/include/python3.10',
+ 'INCLUDEPY': '/usr/include/python3.11',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 755',
- 'INSTSONAME': 'libpython3.10.so.1.0',
+ 'INSTSONAME': 'libpython3.11.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -shared',
  'LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
             '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'LDFLAGS_NODIST': '',
- 'LDLIBRARY': 'libpython3.10.so',
+ 'LDLIBRARY': 'libpython3.11.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'gcc -shared -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
              '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
- 'LDVERSION': '3.10',
+ 'LDVERSION': '3.11',
  'LIBC': '',
- 'LIBDEST': '/usr/lib/python3.10',
+ 'LIBDEST': '/usr/lib/python3.11',
  'LIBDIR': '/usr/lib',
+ 'LIBEXPAT_A': 'Modules/expat/libexpat.a',
+ 'LIBEXPAT_CFLAGS': '-DNDEBUG -g -fwrapv -O3 -Wall -march=armv7-a '
+                    '-mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                    '-fstack-protector-strong -fno-plt -fexceptions         '
+                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                    '-Werror=format-security         -fstack-clash-protection '
+                    '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                    '-fstack-protector-strong -fno-plt -fexceptions         '
+                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                    '-Werror=format-security         -fstack-clash-protection '
+                    '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                    '-fstack-protector-strong -fno-plt -fexceptions         '
+                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                    '-Werror=format-security         -fstack-clash-protection '
+                    '-std=c11 -Werror=implicit-function-declaration '
+                    '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
+                    '-fPIC -fPIC',
+ 'LIBEXPAT_HEADERS': '\\',
+ 'LIBEXPAT_OBJS': '\\',
  'LIBFFI_INCLUDEDIR': '',
  'LIBM': '-lm',
+ 'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
+ 'LIBMPDEC_CFLAGS': '-DCONFIG_32=1 -DANSI=1 -DNDEBUG -g -fwrapv -O3 -Wall '
+                    '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                    '-fstack-protector-strong -fno-plt -fexceptions         '
+                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                    '-Werror=format-security         -fstack-clash-protection '
+                    '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                    '-fstack-protector-strong -fno-plt -fexceptions         '
+                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                    '-Werror=format-security         -fstack-clash-protection '
+                    '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                    '-fstack-protector-strong -fno-plt -fexceptions         '
+                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                    '-Werror=format-security         -fstack-clash-protection '
+                    '-std=c11 -Werror=implicit-function-declaration '
+                    '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
+                    '-fPIC -fPIC',
+ 'LIBMPDEC_HEADERS': '\\',
+ 'LIBMPDEC_OBJS': '\\',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/usr/lib/pkgconfig',
- 'LIBPL': '/usr/lib/python3.10/config-3.10-arm-linux-gnueabihf',
+ 'LIBPL': '/usr/lib/python3.11/config-3.11-arm-linux-gnueabihf',
  'LIBPYTHON': '',
- 'LIBRARY': 'libpython3.10.a',
- 'LIBRARY_DEPS': 'libpython3.10.a libpython3.10.so libpython3.so',
+ 'LIBRARY': 'libpython3.11.a',
+ 'LIBRARY_DEPS': 'libpython3.11.a libpython3.11.so libpython3.so',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
- 'LIBS': '-lcrypt -ldl  -lm',
+ 'LIBS': '-ldl',
  'LIBSUBDIRS': 'asyncio \\',
  'LINKCC': 'gcc',
  'LINKFORSHARED': '-Xlinker -export-dynamic',
+ 'LINK_PYTHON_DEPS': 'libpython3.11.a libpython3.11.so libpython3.so',
+ 'LINK_PYTHON_OBJS': '-L. -lpython3.11',
  'LIPO_32BIT_FLAGS': '',
  'LIPO_INTEL64_FLAGS': '',
  'LLVM_PROF_ERR': 'no',
@@ -591,7 +690,7 @@ build_time_vars = {'ABIFLAGS': '',
  'LOCALMODLIBS': '',
  'MACHDEP': 'linux',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/usr/lib/python3.10',
+ 'MACHDESTLIB': '/usr/lib/python3.11',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'gcc',
  'MAJOR_IN_MKDEV': 0,
@@ -599,25 +698,213 @@ build_time_vars = {'ABIFLAGS': '',
  'MAKESETUP': './Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
- 'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
-                   '_operator  _collections  _abc  itertools  atexit  _signal  '
-                   '_stat  time  _thread  _locale  _io  faulthandler  '
-                   '_tracemalloc  _symtable  xxsubtype',
+ 'MODBUILT_NAMES': 'atexit  faulthandler  posix  _signal  _tracemalloc  '
+                   '_codecs  _collections  errno  _io  itertools  _sre  '
+                   '_thread  time  _weakref  _abc  _functools  _locale  '
+                   '_operator  _stat  _symtable  pwd  xxsubtype',
  'MODDISABLED_NAMES': '',
  'MODLIBS': '',
- 'MODOBJS': 'Modules/posixmodule.o  Modules/errnomodule.o  '
-            'Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  '
-            'Modules/_weakref.o  Modules/_functoolsmodule.o  '
-            'Modules/_operator.o  Modules/_collectionsmodule.o  '
-            'Modules/_abc.o  Modules/itertoolsmodule.o  '
-            'Modules/atexitmodule.o  Modules/signalmodule.o  Modules/_stat.o  '
-            'Modules/timemodule.o  Modules/_threadmodule.o  '
-            'Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o '
-            'Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o '
-            'Modules/textio.o Modules/stringio.o  Modules/faulthandler.o  '
-            'Modules/_tracemalloc.o  Modules/symtablemodule.o  '
+ 'MODOBJS': 'Modules/atexitmodule.o  Modules/faulthandler.o  '
+            'Modules/posixmodule.o  Modules/signalmodule.o  '
+            'Modules/_tracemalloc.o  Modules/_codecsmodule.o  '
+            'Modules/_collectionsmodule.o  Modules/errnomodule.o  '
+            'Modules/_io/_iomodule.o Modules/_io/iobase.o Modules/_io/fileio.o '
+            'Modules/_io/bytesio.o Modules/_io/bufferedio.o '
+            'Modules/_io/textio.o Modules/_io/stringio.o  '
+            'Modules/itertoolsmodule.o  Modules/_sre/sre.o  '
+            'Modules/_threadmodule.o  Modules/timemodule.o  '
+            'Modules/_weakref.o  Modules/_abc.o  Modules/_functoolsmodule.o  '
+            'Modules/_localemodule.o  Modules/_operator.o  Modules/_stat.o  '
+            'Modules/symtablemodule.o  Modules/pwdmodule.o  '
             'Modules/xxsubtype.o',
+ 'MODSHARED_NAMES': '',
+ 'MODULE_ARRAY_STATE': 'yes',
+ 'MODULE_ATEXIT_LDFLAGS': '',
+ 'MODULE_AUDIOOP_LDFLAGS': '-lm',
+ 'MODULE_AUDIOOP_STATE': 'yes',
+ 'MODULE_BINASCII_CFLAGS': '-DUSE_ZLIB_CRC32',
+ 'MODULE_BINASCII_LDFLAGS': '-lz',
+ 'MODULE_BINASCII_STATE': 'yes',
+ 'MODULE_CMATH_DEPS': './Modules/_math.h',
+ 'MODULE_CMATH_LDFLAGS': '-lm',
+ 'MODULE_CMATH_STATE': 'yes',
+ 'MODULE_ERRNO_LDFLAGS': '',
+ 'MODULE_FAULTHANDLER_LDFLAGS': '',
+ 'MODULE_FCNTL_LDFLAGS': '',
+ 'MODULE_FCNTL_STATE': 'yes',
+ 'MODULE_GRP_STATE': 'yes',
+ 'MODULE_ITERTOOLS_LDFLAGS': '',
+ 'MODULE_MATH_DEPS': './Modules/_math.h',
+ 'MODULE_MATH_LDFLAGS': '-lm',
+ 'MODULE_MATH_STATE': 'yes',
+ 'MODULE_MMAP_STATE': 'yes',
+ 'MODULE_NIS_CFLAGS': '-I/usr/include/tirpc',
+ 'MODULE_NIS_LDFLAGS': '-lnsl -ltirpc',
+ 'MODULE_NIS_STATE': 'yes',
  'MODULE_OBJS': '\\',
+ 'MODULE_OSSAUDIODEV_LDFLAGS': '',
+ 'MODULE_OSSAUDIODEV_STATE': 'yes',
+ 'MODULE_POSIX_LDFLAGS': '',
+ 'MODULE_PWD_LDFLAGS': '',
+ 'MODULE_PWD_STATE': 'yes',
+ 'MODULE_PYEXPAT_CFLAGS': '',
+ 'MODULE_PYEXPAT_DEPS': '',
+ 'MODULE_PYEXPAT_LDFLAGS': '-lexpat',
+ 'MODULE_PYEXPAT_STATE': 'yes',
+ 'MODULE_RESOURCE_STATE': 'yes',
+ 'MODULE_SELECT_STATE': 'yes',
+ 'MODULE_SPWD_STATE': 'yes',
+ 'MODULE_SYSLOG_STATE': 'yes',
+ 'MODULE_TERMIOS_STATE': 'yes',
+ 'MODULE_TIME_LDFLAGS': '',
+ 'MODULE_TIME_STATE': 'yes',
+ 'MODULE_UNICODEDATA_DEPS': './Modules/unicodedata_db.h '
+                            './Modules/unicodename_db.h',
+ 'MODULE_UNICODEDATA_STATE': 'yes',
+ 'MODULE_XXLIMITED_35_STATE': 'yes',
+ 'MODULE_XXLIMITED_STATE': 'yes',
+ 'MODULE_XXSUBTYPE_LDFLAGS': '',
+ 'MODULE_ZLIB_CFLAGS': '',
+ 'MODULE_ZLIB_LDFLAGS': '-lz',
+ 'MODULE_ZLIB_STATE': 'yes',
+ 'MODULE__ABC_LDFLAGS': '',
+ 'MODULE__ASYNCIO_STATE': 'yes',
+ 'MODULE__BISECT_STATE': 'yes',
+ 'MODULE__BLAKE2_CFLAGS': '',
+ 'MODULE__BLAKE2_DEPS': './Modules/_blake2/impl/blake2-config.h '
+                        './Modules/_blake2/impl/blake2-impl.h '
+                        './Modules/_blake2/impl/blake2.h '
+                        './Modules/_blake2/impl/blake2b-load-sse2.h '
+                        './Modules/_blake2/impl/blake2b-load-sse41.h '
+                        './Modules/_blake2/impl/blake2b-ref.c '
+                        './Modules/_blake2/impl/blake2b-round.h '
+                        './Modules/_blake2/impl/blake2b.c '
+                        './Modules/_blake2/impl/blake2s-load-sse2.h '
+                        './Modules/_blake2/impl/blake2s-load-sse41.h '
+                        './Modules/_blake2/impl/blake2s-load-xop.h '
+                        './Modules/_blake2/impl/blake2s-ref.c '
+                        './Modules/_blake2/impl/blake2s-round.h '
+                        './Modules/_blake2/impl/blake2s.c '
+                        './Modules/_blake2/blake2module.h ./Modules/hashlib.h',
+ 'MODULE__BLAKE2_LDFLAGS': '',
+ 'MODULE__BLAKE2_STATE': 'yes',
+ 'MODULE__BZ2_CFLAGS': '',
+ 'MODULE__BZ2_LDFLAGS': '-lbz2',
+ 'MODULE__BZ2_STATE': 'yes',
+ 'MODULE__CODECS_CN_STATE': 'yes',
+ 'MODULE__CODECS_HK_STATE': 'yes',
+ 'MODULE__CODECS_ISO2022_STATE': 'yes',
+ 'MODULE__CODECS_JP_STATE': 'yes',
+ 'MODULE__CODECS_KR_STATE': 'yes',
+ 'MODULE__CODECS_LDFLAGS': '',
+ 'MODULE__CODECS_TW_STATE': 'yes',
+ 'MODULE__COLLECTIONS_LDFLAGS': '',
+ 'MODULE__CONTEXTVARS_STATE': 'yes',
+ 'MODULE__CRYPT_CFLAGS': '',
+ 'MODULE__CRYPT_LDFLAGS': '-lcrypt',
+ 'MODULE__CRYPT_STATE': 'yes',
+ 'MODULE__CSV_STATE': 'yes',
+ 'MODULE__CTYPES_DEPS': './Modules/_ctypes/ctypes.h',
+ 'MODULE__CTYPES_TEST_LDFLAGS': '-lm',
+ 'MODULE__CTYPES_TEST_STATE': 'yes',
+ 'MODULE__DATETIME_LDFLAGS': '-lm',
+ 'MODULE__DATETIME_STATE': 'yes',
+ 'MODULE__DECIMAL_CFLAGS': '-DCONFIG_32=1 -DANSI=1',
+ 'MODULE__DECIMAL_DEPS': './Modules/_decimal/docstrings.h',
+ 'MODULE__DECIMAL_LDFLAGS': '-lmpdec',
+ 'MODULE__DECIMAL_STATE': 'yes',
+ 'MODULE__ELEMENTTREE_CFLAGS': '',
+ 'MODULE__ELEMENTTREE_DEPS': './Modules/pyexpat.c',
+ 'MODULE__ELEMENTTREE_STATE': 'yes',
+ 'MODULE__FUNCTOOLS_LDFLAGS': '',
+ 'MODULE__GDBM_CFLAGS': '',
+ 'MODULE__GDBM_LDFLAGS': '-lgdbm',
+ 'MODULE__GDBM_STATE': 'yes',
+ 'MODULE__HASHLIB_CFLAGS': '',
+ 'MODULE__HASHLIB_DEPS': './Modules/hashlib.h',
+ 'MODULE__HASHLIB_LDFLAGS': '-lcrypto',
+ 'MODULE__HASHLIB_STATE': 'yes',
+ 'MODULE__HEAPQ_STATE': 'yes',
+ 'MODULE__IO_CFLAGS': '-I./Modules/_io',
+ 'MODULE__IO_DEPS': './Modules/_io/_iomodule.h',
+ 'MODULE__IO_LDFLAGS': '',
+ 'MODULE__IO_STATE': 'yes',
+ 'MODULE__JSON_STATE': 'yes',
+ 'MODULE__LOCALE_LDFLAGS': '',
+ 'MODULE__LSPROF_STATE': 'yes',
+ 'MODULE__LZMA_CFLAGS': '',
+ 'MODULE__LZMA_LDFLAGS': '-llzma',
+ 'MODULE__LZMA_STATE': 'yes',
+ 'MODULE__MD5_DEPS': './Modules/hashlib.h',
+ 'MODULE__MD5_STATE': 'yes',
+ 'MODULE__MULTIBYTECODEC_STATE': 'yes',
+ 'MODULE__MULTIPROCESSING_CFLAGS': '-I./Modules/_multiprocessing',
+ 'MODULE__MULTIPROCESSING_STATE': 'yes',
+ 'MODULE__OPCODE_STATE': 'yes',
+ 'MODULE__OPERATOR_LDFLAGS': '',
+ 'MODULE__PICKLE_STATE': 'yes',
+ 'MODULE__POSIXSHMEM_CFLAGS': '-I./Modules/_multiprocessing',
+ 'MODULE__POSIXSHMEM_LDFLAGS': '',
+ 'MODULE__POSIXSHMEM_STATE': 'yes',
+ 'MODULE__POSIXSUBPROCESS_STATE': 'yes',
+ 'MODULE__QUEUE_STATE': 'yes',
+ 'MODULE__RANDOM_STATE': 'yes',
+ 'MODULE__SCPROXY_STATE': 'n/a',
+ 'MODULE__SHA1_DEPS': './Modules/hashlib.h',
+ 'MODULE__SHA1_STATE': 'yes',
+ 'MODULE__SHA256_DEPS': './Modules/hashlib.h',
+ 'MODULE__SHA256_STATE': 'yes',
+ 'MODULE__SHA3_DEPS': './Modules/_sha3/sha3.c ./Modules/_sha3/sha3.h '
+                      './Modules/hashlib.h',
+ 'MODULE__SHA3_STATE': 'yes',
+ 'MODULE__SHA512_DEPS': './Modules/hashlib.h',
+ 'MODULE__SHA512_STATE': 'yes',
+ 'MODULE__SIGNAL_LDFLAGS': '',
+ 'MODULE__SOCKET_DEPS': './Modules/socketmodule.h ./Modules/addrinfo.h '
+                        './Modules/getaddrinfo.c ./Modules/getnameinfo.c',
+ 'MODULE__SOCKET_STATE': 'yes',
+ 'MODULE__SQLITE3_CFLAGS': '-I./Modules/_sqlite',
+ 'MODULE__SQLITE3_DEPS': './Modules/_sqlite/connection.h '
+                         './Modules/_sqlite/cursor.h '
+                         './Modules/_sqlite/microprotocols.h '
+                         './Modules/_sqlite/module.h '
+                         './Modules/_sqlite/prepare_protocol.h '
+                         './Modules/_sqlite/row.h ./Modules/_sqlite/util.h',
+ 'MODULE__SQLITE3_LDFLAGS': '-lsqlite3',
+ 'MODULE__SQLITE3_STATE': 'yes',
+ 'MODULE__SRE_LDFLAGS': '',
+ 'MODULE__SSL_CFLAGS': '',
+ 'MODULE__SSL_DEPS': './Modules/_ssl.h ./Modules/_ssl/cert.c '
+                     './Modules/_ssl/debughelpers.c ./Modules/_ssl/misc.c '
+                     './Modules/_ssl_data.h ./Modules/_ssl_data_111.h '
+                     './Modules/_ssl_data_300.h ./Modules/socketmodule.h',
+ 'MODULE__SSL_LDFLAGS': '-lssl -lcrypto',
+ 'MODULE__SSL_STATE': 'yes',
+ 'MODULE__STATISTICS_LDFLAGS': '-lm',
+ 'MODULE__STATISTICS_STATE': 'yes',
+ 'MODULE__STAT_LDFLAGS': '',
+ 'MODULE__STRUCT_STATE': 'yes',
+ 'MODULE__SYMTABLE_LDFLAGS': '',
+ 'MODULE__TESTBUFFER_STATE': 'yes',
+ 'MODULE__TESTCAPI_DEPS': './Modules/testcapi_long.h',
+ 'MODULE__TESTCAPI_STATE': 'yes',
+ 'MODULE__TESTCLINIC_STATE': 'yes',
+ 'MODULE__TESTIMPORTMULTIPLE_STATE': 'yes',
+ 'MODULE__TESTINTERNALCAPI_STATE': 'yes',
+ 'MODULE__TESTMULTIPHASE_STATE': 'yes',
+ 'MODULE__THREAD_LDFLAGS': '',
+ 'MODULE__TKINTER_CFLAGS': '-Wno-strict-prototypes -DWITH_APPINIT=1',
+ 'MODULE__TKINTER_LDFLAGS': '-ltk8.6 -ltkstub8.6 -ltcl8.6 -ltclstub8.6',
+ 'MODULE__TKINTER_STATE': 'yes',
+ 'MODULE__TRACEMALLOC_LDFLAGS': '',
+ 'MODULE__TYPING_STATE': 'yes',
+ 'MODULE__UUID_CFLAGS': '-I/usr/include/uuid',
+ 'MODULE__UUID_LDFLAGS': '-luuid',
+ 'MODULE__UUID_STATE': 'yes',
+ 'MODULE__WEAKREF_LDFLAGS': '',
+ 'MODULE__XXSUBINTERPRETERS_STATE': 'yes',
+ 'MODULE__XXTESTFUZZ_STATE': 'yes',
+ 'MODULE__ZONEINFO_STATE': 'yes',
  'MULTIARCH': 'arm-linux-gnueabihf',
  'MULTIARCH_CPPFLAGS': '-DMULTIARCH=\\"arm-linux-gnueabihf\\"',
  'MVWDELCH_IS_EXPRESSION': 1,
@@ -657,12 +944,13 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python -E',
+ 'PYTHON_FOR_BUILD_DEPS': 'python',
+ 'PYTHON_FOR_FREEZE': './_bootstrap_python',
  'PYTHON_FOR_REGEN': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g '
-                             '-fwrapv -O3 -Wall -march=armv7-a '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-DNDEBUG -g -fwrapv -O3 -Wall -march=armv7-a '
                              '-mfloat-abi=hard -mfpu=neon -O3 -pipe '
                              '-fstack-protector-strong -fno-plt '
                              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
@@ -677,16 +965,13 @@ build_time_vars = {'ABIFLAGS': '',
                              '-fstack-protector-strong -fno-plt '
                              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wformat -Werror=format-security         '
-                             '-fstack-clash-protection -std=c99 -Wextra '
-                             '-Wno-unused-result -Wno-unused-parameter '
-                             '-Wno-missing-field-initializers '
+                             '-fstack-clash-protection -std=c11 '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
                              '-I./Include -fPIC -DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-              '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
-              '-fstack-protector-strong -fno-plt -fexceptions         '
-              '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+ 'PY_CFLAGS': '-DNDEBUG -g -fwrapv -O3 -Wall -march=armv7-a -mfloat-abi=hard '
+              '-mfpu=neon -O3 -pipe -fstack-protector-strong -fno-plt '
+              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
               '-Werror=format-security         -fstack-clash-protection '
               '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
               '-fstack-protector-strong -fno-plt -fexceptions         '
@@ -696,13 +981,11 @@ build_time_vars = {'ABIFLAGS': '',
               '-fstack-protector-strong -fno-plt -fexceptions         '
               '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
               '-Werror=format-security         -fstack-clash-protection',
- 'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
-                     '-Wno-unused-parameter -Wno-missing-field-initializers '
-                     '-Werror=implicit-function-declaration '
+ 'PY_CFLAGS_NODIST': '-std=c11 -Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
-                   '-Wall -march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
+ 'PY_CORE_CFLAGS': '-DNDEBUG -g -fwrapv -O3 -Wall -march=armv7-a '
+                   '-mfloat-abi=hard -mfpu=neon -O3 -pipe '
                    '-fstack-protector-strong -fno-plt -fexceptions         '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
@@ -714,10 +997,9 @@ build_time_vars = {'ABIFLAGS': '',
                    '-fstack-protector-strong -fno-plt -fexceptions         '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers '
-                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
-                   '-I./Include/internal -I. -I./Include -fPIC -DPy_BUILD_CORE',
+                   '-std=c11 -Werror=implicit-function-declaration '
+                   '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
+                   '-fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
                     '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'PY_CPPFLAGS': '-I. -I./Include',
@@ -726,11 +1008,15 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
                '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'PY_LDFLAGS_NODIST': '',
+ 'PY_LDFLAGS_NOLTO': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
+                     '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'PY_SQLITE_ENABLE_LOAD_EXTENSION': 1,
+ 'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv '
-                        '-O3 -Wall -march=armv7-a -mfloat-abi=hard -mfpu=neon '
-                        '-O3 -pipe -fstack-protector-strong -fno-plt '
+ 'PY_STDMODULE_CFLAGS': '-DNDEBUG -g -fwrapv -O3 -Wall -march=armv7-a '
+                        '-mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                        '-fstack-protector-strong -fno-plt '
                         '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                         '-Werror=format-security         '
                         '-fstack-clash-protection -march=armv7-a '
@@ -743,27 +1029,26 @@ build_time_vars = {'ABIFLAGS': '',
                         '-fstack-protector-strong -fno-plt '
                         '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                         '-Werror=format-security         '
-                        '-fstack-clash-protection -std=c99 -Wextra '
-                        '-Wno-unused-result -Wno-unused-parameter '
-                        '-Wno-missing-field-initializers '
+                        '-fstack-clash-protection -std=c11 '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
                         '-I./Include -fPIC',
+ 'PY_SUPPORT_TIER': 3,
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
+ 'Py_STATS': 0,
  'Py_TRACE_REFS': 0,
  'QUICKTESTOPTS': '-x test_subprocess test_io test_lib2to3 \\',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.10.10',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.11.3',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
- 'SHLIBS': '-lcrypt -ldl  -lm',
+ 'SHLIBS': '-ldl',
  'SHLIB_SUFFIX': '.so',
- 'SHM_NEEDS_LIBRT': 0,
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
  'SITEPATH': '',
  'SIZEOF_DOUBLE': 8,
@@ -784,8 +1069,13 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-310-arm-linux-gnueabihf',
- 'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
+ 'SOABI': 'cpython-311-arm-linux-gnueabihf',
+ 'SRCDIRS': 'Modules   Modules/_blake2   Modules/_ctypes   Modules/_decimal   '
+            'Modules/_decimal/libmpdec   Modules/_io   '
+            'Modules/_multiprocessing   Modules/_sha3   Modules/_sqlite   '
+            'Modules/_sre   Modules/_xxtestfuzz   Modules/cjkcodecs   '
+            'Modules/expat   Objects   Parser   Programs   Python   '
+            'Python/frozen_modules   Python/deepfreeze',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STATIC_LIBPYTHON': 1,
  'STDC_HEADERS': 1,
@@ -795,13 +1085,11 @@ build_time_vars = {'ABIFLAGS': '',
  'SUBDIRSTOO': 'Include Lib Misc',
  'SYSLIBS': '-lm',
  'SYS_SELECT_WITH_SYS_TIME': 1,
- 'TCLTK_INCLUDES': '',
- 'TCLTK_LIBS': '-ltk8.6 -ltkstub8.6 -ltcl8.6 -ltclstub8.6',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.10.10 ./python',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.11.3 ./python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.10.10 ./python '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.11.3 ./python -E '
                './Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -815,7 +1103,9 @@ build_time_vars = {'ABIFLAGS': '',
  'UNIVERSALSDK': '',
  'UPDATE_FILE': './Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
- 'VERSION': '3.10',
+ 'VERSION': '3.11',
+ 'WASM_ASSETS_DIR': './usr',
+ 'WASM_STDLIB': './usr/lib/python3.11/os.py',
  'WHEEL_PKG_DIR': '',
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DECIMAL_CONTEXTVAR': 1,
@@ -823,14 +1113,15 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_DTRACE': 0,
  'WITH_DYLD': 0,
  'WITH_EDITLINE': 0,
+ 'WITH_FREELISTS': 1,
  'WITH_LIBINTL': 0,
  'WITH_NEXT_FRAMEWORK': 0,
  'WITH_PYMALLOC': 1,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python/src/Python-3.10.10',
- 'abs_srcdir': '/build/python/src/Python-3.10.10',
+ 'abs_builddir': '/build/python/src/Python-3.11.3',
+ 'abs_srcdir': '/build/python/src/Python-3.11.3',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
